@@ -554,9 +554,6 @@ ags_fx_dssi_audio_notify_samplerate_callback(GObject *gobject,
   if(recall_container != NULL){
     g_object_unref(recall_container);
   }
-
-  g_list_free_full(start_recall_channel,
-		   g_object_unref);
 }
 
 void
@@ -793,9 +790,6 @@ ags_fx_dssi_audio_set_audio_channels_callback(AgsAudio *audio,
   if(recall_container != NULL){
     g_object_unref(recall_container);
   }
-
-  g_list_free_full(start_recall_channel,
-		   g_object_unref);
 }
 
 void
@@ -884,9 +878,6 @@ ags_fx_dssi_audio_set_pads_callback(AgsAudio *audio,
   if(recall_container != NULL){
     g_object_unref(recall_container);
   }
-
-  g_list_free_full(start_recall_channel,
-		   g_object_unref);
 }
 
 /**
@@ -1732,9 +1723,6 @@ ags_fx_dssi_audio_load_port(AgsFxDssiAudio *fx_dssi_audio)
     g_object_unref(recall_container);
   }
 
-  g_list_free_full(start_recall_channel,
-		   g_object_unref);
-
   g_list_free_full(start_plugin_port,
 		   (GDestroyNotify) g_object_unref);
 }
